/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user;

import java.time.Instant;
import java.util.List;
import java.util.Map;

import org.keycloak.representations.idm.UserRepresentation;

import com.thedeanda.lorem.LoremIpsum;

public class UserRepresentationTestFactory {

	static final String EMAIL = LoremIpsum.getInstance().getEmail();
	static final String FIRST_NAME = LoremIpsum.getInstance().getFirstName();
	static final String LAST_NAME = LoremIpsum.getInstance().getLastName();
	static final String USER_NAME = LoremIpsum.getInstance().getName();

	static final String EXTERNAL_ID = "external-id-1-ldap";
	static final String EXTERNAL_ID_FALLBACK = "external-id-2-keykloak";
	static final String ROLE_NAME = "VERWALTUNG_USER";

	private static final long CREATED = Instant.now().toEpochMilli();

	static final String ORGANSISATIONS_EINHEIT_ID = "0815";

	private static final String LDAP_ID_KEY = "LDAP_ID";
	static final Map<String, List<String>> ATTRIBUTES = Map.of(LDAP_ID_KEY, List.of(EXTERNAL_ID));

	static final String CLIENT_KEY = "alfa";
	private static final Map<String, List<String>> CLIENT_ROLED = Map.of(CLIENT_KEY, List.of(ROLE_NAME));

	static UserRepresentation createWithAttributes(Map<String, List<String>> attributes) {
		var user = create();
		user.setAttributes(attributes);

		return user;
	}

	public static UserRepresentation create() {
		var user = new UserRepresentation();
		user.setEmail(EMAIL);
		user.setFirstName(FIRST_NAME);
		user.setLastName(LAST_NAME);
		user.setUsername(USER_NAME);
		user.setCreatedTimestamp(CREATED);
		user.setId(EXTERNAL_ID_FALLBACK);
		user.setAttributes(ATTRIBUTES);
		user.setClientRoles(CLIENT_ROLED);

		return user;
	}
}